@@ -8,8 +8,10 @@
 #ifndef _PICASA_XML_H_
 #define _PICASA_XML_H_
 
+#ifdef WITH_ALBUM_SUPPORT
 GSList*
 picasa_xml_parse_album_response (gchar *body);
+#endif /* WITH_ALBUM_SUPPORT */
 
 gchar*
 picasa_xml_parse_upload_response (gchar *body);
